@@ -41,7 +41,7 @@ mm :: C.Montgomery
 mm = 0xFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFFFC2F
 
 repr :: H.Assertion
-repr = H.assertBool mempty (W.eq_vartime 0 (C.from_vartime mm))
+repr = H.assertBool mempty (W.eq_vartime 0 (C.from mm))
 
 add_case :: String -> W.Wider -> W.Wider -> W.Wider -> H.Assertion
 add_case t a b s = do
@@ -49,7 +49,7 @@ add_case t a b s = do
     ((W.from_vartime a + W.from_vartime b) `mod` W.from_vartime m)
     (W.from_vartime s)
   H.assertBool t
-    (W.eq_vartime s (C.from_vartime (C.to_vartime a + C.to_vartime b)))
+    (W.eq_vartime s (C.from (C.to a + C.to b)))
 
 add :: H.Assertion
 add = do
@@ -73,7 +73,7 @@ sub_case t b a d = do
     ((W.from_vartime b - W.from_vartime a) `mod` W.from_vartime m)
     (W.from_vartime d)
   H.assertBool t
-    (W.eq_vartime d (C.from_vartime (C.to_vartime b - C.to_vartime a)))
+    (W.eq_vartime d (C.from (C.to b - C.to a)))
 
 sub :: H.Assertion
 sub = do
@@ -96,7 +96,7 @@ mul_case t a b p = do
     ((W.from_vartime a * W.from_vartime b) `mod` W.from_vartime m)
     (W.from_vartime p)
   H.assertBool t
-    (W.eq_vartime p (C.from_vartime (C.to_vartime a * C.to_vartime b)))
+    (W.eq_vartime p (C.from (C.to a * C.to b)))
 
 mul :: H.Assertion
 mul = do
@@ -122,54 +122,54 @@ instance Q.Arbitrary W.Wider where
   arbitrary = fmap W.to_vartime Q.arbitrary
 
 instance Q.Arbitrary C.Montgomery where
-  arbitrary = fmap C.to_vartime Q.arbitrary
+  arbitrary = fmap C.to Q.arbitrary
 
 add_matches :: W.Wider -> W.Wider -> Bool
 add_matches a b =
-  let ma = C.to_vartime a
-      mb = C.to_vartime b
+  let ma = C.to a
+      mb = C.to b
       ia = W.from_vartime a
       ib = W.from_vartime b
       im = W.from_vartime m
   in  W.eq_vartime
         (W.to_vartime ((ia + ib) `mod` im))
-        (C.from_vartime (ma + mb))
+        (C.from (ma + mb))
 
 mul_matches :: W.Wider -> W.Wider -> Bool
 mul_matches a b =
-  let ma = C.to_vartime a
-      mb = C.to_vartime b
+  let ma = C.to a
+      mb = C.to b
       ia = W.from_vartime a
       ib = W.from_vartime b
       im = W.from_vartime m
   in  W.eq_vartime
         (W.to_vartime ((ia * ib) `mod` im))
-        (C.from_vartime (ma * mb))
+        (C.from (ma * mb))
 
 sqr_matches :: W.Wider -> Bool
 sqr_matches a =
-  let ma = C.to_vartime a
+  let ma = C.to a
       ia = W.from_vartime a
       im = W.from_vartime m
   in  W.eq_vartime
         (W.to_vartime ((ia * ia) `mod` im))
-        (C.from_vartime (C.sqr ma))
+        (C.from (C.sqr ma))
 
 exp_matches :: C.Montgomery -> W.Wider -> Bool
 exp_matches a b =
-  let ia = W.from_vartime (C.from_vartime a)
+  let ia = W.from_vartime (C.from a)
       nb = fromIntegral (W.from_vartime b)
       nm = fromIntegral (W.from_vartime m)
   in  W.eq_vartime
         (W.to_vartime (modexp ia nb nm))
-        (C.from_vartime (C.exp a b))
+        (C.from (C.exp a b))
 
 inv_valid :: Q.NonZero C.Montgomery -> Bool
 inv_valid (Q.NonZero s) = C.eq_vartime (C.inv s * s) 1
 
 odd_correct :: C.Montgomery -> Bool
 odd_correct w =
-  C.odd_vartime w == I.integerTestBit (W.from_vartime (C.from_vartime w)) 0
+  C.odd_vartime w == I.integerTestBit (W.from_vartime (C.from w)) 0
 
 tests :: TestTree
 tests = testGroup "montgomery tests (curve)" [
